@@ -9,21 +9,22 @@
         enumResultPrintTerse()	print enumeration result object, tersely
         enumSample()		monte carlo sampling of outcomes
 
-   Michael Maurer, Apr 2002
-
- *  This package is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+   Copyright (C) Apr 2002, Michael Maurer.
  *
- *  This package is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program gives you software freedom; you can copy, convey,
+ * propagate, redistribute and/or modify this program under the terms of
+ * the GNU General Public License (GPL) as published by the Free Software
+ * Foundation (FSF), either version 3 of the License, or (at your option)
+ * any later version of the GPL published by the FSF.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this package; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
- *  MA 02110-1301, USA.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program in a file in the toplevel directory called "GPLv3".
+ * If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <stdio.h>
@@ -159,7 +160,7 @@ static enum_gameparams_t enum_gameparams[] = {
         result->nsharehi[i][H]++;					\
         result->nsharelo[i][L]++;					\
         result->nshare[i][H][L]++;					\
-        if (potfrac == 1)						\
+        if (potfrac > 0.99)						\
           result->nscoop[i]++;						\
         result->ev[i] += potfrac;					\
       }									\
